---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: starbase
---
**System information (please complete the following information):**
 - OS: [e.g. Darwin/18.0.0-x86_64-64bit]
 - Python Version: [e.g. CPython/3.7.2;Clang 10.0.0]
 - SDK Version: [e.g. 0.13.0.a4]

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Runnable code reproducing the error.
```
from cognite.client import CogniteClient

client = CogniteClient()

client.assets.get_assets()
```
**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.



**Additional context**
Add any other context about the problem here.
